@@ -191,8 +191,8 @@ class TestConfiguration(unittest.TestCase):
         check = Configuration._check_directory(cfg, "c:\\my_dir")
         mock_isdir.assert_called_with("c:\\my_dir\\BatchAppsData")
         mock_mkdir.assert_called_with("c:\\my_dir\\BatchAppsData")
-        mock_open.assert_called_with("c:\\my_dir\\BatchAppsData\\gb_test", 'w')
-        mock_rem.assert_called_with("c:\\my_dir\\BatchAppsData\\gb_test")
+        mock_open.assert_called_with("c:\\my_dir\\BatchAppsData\\aba_test", 'w')
+        mock_rem.assert_called_with("c:\\my_dir\\BatchAppsData\\aba_test")
         self.assertTrue(check)
 
     @mock.patch.object(batchapps.config.os.path, 'isdir')
@@ -418,11 +418,11 @@ class TestConfiguration(unittest.TestCase):
         cfg.job_type = "TestApp"
         ept = Configuration.endpoint(cfg)
         self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'http://test')
-        self.assertEqual(ept, 'http://test')
+        self.assertEqual(ept, 'test')
 
-        ept = Configuration.endpoint(cfg, "http://new_test")
-        self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'http://new_test')
-        self.assertEqual(ept, 'http://new_test')
+        ept = Configuration.endpoint(cfg, "https://new_test/")
+        self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'https://new_test/')
+        self.assertEqual(ept, 'new_test/')
 
     def test_config_logging_level(self):
         """Test logging_level"""
